@@ -3,15 +3,29 @@ use strict;
 use warnings;
 
 package Stenciller::Plugin::ToHtmlPreBlock;
-our $VERSION = '0.1300'; # VERSION:
+our $VERSION = '0.1301'; # VERSION:
 # ABSTRACT: A plugin that transforms to html
 
 use Moose;
 use List::AllUtils qw/first_index/;
 with 'Stenciller::Transformer';
 
+use Types::Standard qw/Bool Str Maybe/;
+use MooseX::AttributeShortcuts;
 use HTML::Entities 'encode_entities';
 
+has output_also_as_html => (
+    is => 'ro',
+    isa => Bool,
+    default => 0,
+);
+has separator => (
+    is => 'ro',
+    isa => Maybe[Str],
+    predicate => 1,
+);
+
+
 sub transform {
     my $self = shift;
     my $transform_args = shift;
@@ -29,7 +43,9 @@ sub transform {
                      $self->pre($stencil->all_input),
                      $self->normal($stencil->all_between),
                      $self->pre($stencil->all_output),
-                     $self->normal($stencil->all_after_output);
+                     $self->output_also_as_html ? $self->normal($stencil->all_output) : (),
+                     $self->normal($stencil->all_after_output,
+                     $self->has_separator && $i < $self->stenciller->max_stencil_index ? $self->separator : ());
 
     }
     return join "\n" => @out;
@@ -64,7 +80,7 @@ Stenciller::Plugin::ToHtmlPreBlock - A plugin that transforms to html
 
 =head1 VERSION
 
-Version 0.1300, released 2015-11-22.
+Version 0.1301, released 2015-11-23.
 
 
 
@@ -80,6 +96,20 @@ This plugin to L<Stenciller> places the C<before_input>, C<between> and C<after_
 
 Content that will be placed in C<pre> tags (input and output sections in stencils) also have four leading spaces removed.
 
+=head1 ATTRIBUTES
+
+=head2 output_also_as_html
+
+Default: C<0>
+
+If set to a true value, the contents of C<output> in stencils is rendered as html (directly following the pre-block).
+
+=head2 separator
+
+Default: C<undef>
+
+When set, this text is used to separate two stencils.
+
 =head1 METHODS
 
 =head2 transform
