@@ -3,12 +3,20 @@ use strict;
 use warnings;
 
 package Stenciller::Plugin::ToUnparsedText;
-our $VERSION = '0.1300'; # VERSION:
+our $VERSION = '0.1301'; # VERSION:
 # ABSTRACT: A plugin that doesn't transform the text
 
 use Moose;
 use List::AllUtils qw/first_index/;
 with 'Stenciller::Transformer';
+use Types::Standard qw/Bool/;
+
+has text_as_html_pod => (
+    is => 'ro',
+    isa => Bool,
+    default => 0,
+);
+
 
 sub transform {
     my $self = shift;
@@ -24,17 +32,30 @@ sub transform {
         next STENCIL if $self->should_skip_stencil($stencil, $transform_args);
 
         push @out => '',
-                     $stencil->all_before_input, '',
+                     $self->maybe_as_html_pod($stencil->all_before_input), '',
                      $stencil->all_input, '',
-                     $stencil->all_between, '',
+                     $self->maybe_as_html_pod($stencil->all_between), '',
                      $stencil->all_output, '',
-                     $stencil->all_after_output, '';
+                     $self->maybe_as_html_pod($stencil->all_after_output), '';
     }
     my $content = join "\n" => '', @out, '';
     $content =~ s{\v{2,}}{\n\n}g;
     return $content;
 }
 
+sub maybe_as_html_pod {
+    my $self = shift;
+    my @text = @_;
+
+    return @text if !$self->text_as_html_pod;
+    return @text if !scalar @text;
+
+    unshift @text => '', '=begin html', '';
+    push @text => '', '=end html', '';
+    return @text;
+
+}
+
 1;
 
 __END__
@@ -49,7 +70,7 @@ Stenciller::Plugin::ToUnparsedText - A plugin that doesn't transform the text
 
 =head1 VERSION
 
-Version 0.1300, released 2015-11-22.
+Version 0.1301, released 2015-11-23.
 
 
 
@@ -79,6 +100,15 @@ If this plugin is used via L<Pod::Elemental::Transformer::Stenciller> it could b
     # includes only the header_lines
     :stenciller ToUnparsedText atestfile-1.stencil { stencils => [] }
 
+=head1 ATTRIBUTES
+
+=head2 text_as_html_pod
+
+Default: 0
+
+If set to a true value, the parts that are neither C<input> or C<output> will be rendered between C<=begin html> and C<=end html>. This is useful
+when rendering the same stencils to html examples files as well as including in pod.
+
 =head1 METHODS
 
 =head2 transform
